@@ -6,4 +6,4 @@ from reinvent_scoring.scoring.component_parameters import ComponentParameters
 from reinvent_scoring.scoring.score_summary import FinalSummary, ComponentSummary, LoggableComponent
 from reinvent_scoring.scoring.score_transformations import TransformationFactory
 from reinvent_scoring.scoring.scoring_function_factory import ScoringFunctionFactory
-from reinvent_scoring.scoring.scoring_function_parameters import ScoringFuncionParameters
+from reinvent_scoring.scoring.scoring_function_parameters import ScoringFunctionParameters, ScoringFuncionParameters
