@@ -7,6 +7,6 @@ class ComponentParameters:
     component_type: str
     name: str
     weight: float
-    smiles: List[str]
-    model_path: str
+    smiles: List[str] = None
+    model_path: str = None
     specific_parameters: dict = None
