@@ -8,5 +8,5 @@ class DiversityFilter:
     def __new__(cls, parameters: DiversityFilterParameters) -> BaseDiversityFilter:
         all_filters = dict(NoFilter=NoFilter,
                            NoFilterWithPenalty=NoFilterWithPenalty)
-        div_filter = all_filters.get(parameters.name)
+        div_filter = all_filters.get(parameters.name, KeyError(f"Invalid filter name: `{parameters.name}'"))
         return div_filter(parameters)
